==> commons-0.8.1-sources.jar: com/flybits/internal/db/CommonsDatabase.java <==
package com.flybits.internal.db;

import android.arch.persistence.db.SupportSQLiteDatabase;
import android.arch.persistence.room.Database;
import android.arch.persistence.room.Room;
import android.arch.persistence.room.RoomDatabase;
import android.arch.persistence.room.migration.Migration;
import android.content.Context;

import com.flybits.commons.library.models.User;
import com.flybits.internal.db.models.CachingEntry;

@Database(entities = {User.class, CachingEntry.class}, version = 2)
public abstract class CommonsDatabase extends RoomDatabase {

    private static CommonsDatabase INSTANCE;

    public abstract UserDAO userDao();
    public abstract CachingEntryDAO cachingEntryDAO();

    public static CommonsDatabase getDatabase(Context context) {
        if (INSTANCE == null) {
            INSTANCE =
                    Room.databaseBuilder(context, CommonsDatabase.class, "commons-flybits-db")
                            .addMigrations(MIGRATION_1_2)
                            .build();
                   /*
                    Room.inMemoryDatabaseBuilder(context.getApplicationContext(), ContextDatabase.class)
                            // To simplify the codelab, allow queries on the main thread.
                            // Don't do this on a real app! See PersistenceBasicSample for an example.
                            .allowMainThreadQueries()
                            .build();
                    */
        }
        return INSTANCE;
    }

    //TODO: This is a placeholder to remind that migrations need to take place between version nums.
    private static final Migration MIGRATION_1_2 = new Migration(1, 2) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
          //  database.execSQL("DROP TABLE IF EXISTS user");
          //  database.execSQL("DROP TABLE IF EXISTS cachingentry");
        }
    };

    public static void destroyInstance() {
        INSTANCE = null;
    }
}

==> commons-0.8.2-sources.jar: com/flybits/internal/db/CommonsDatabase.java <==
package com.flybits.internal.db;

import android.arch.persistence.db.SupportSQLiteDatabase;
import android.arch.persistence.room.Database;
import android.arch.persistence.room.Room;
import android.arch.persistence.room.RoomDatabase;
import android.arch.persistence.room.migration.Migration;
import android.content.Context;

import com.flybits.commons.library.models.User;
import com.flybits.internal.db.models.CachingEntry;

@Database(entities = {User.class, CachingEntry.class}, version = 2)
public abstract class CommonsDatabase extends RoomDatabase {

    private static CommonsDatabase INSTANCE;

    public abstract UserDAO userDao();
    public abstract CachingEntryDAO cachingEntryDAO();

    public static CommonsDatabase getDatabase(Context context) {
        if (INSTANCE == null) {
            INSTANCE =
                    Room.databaseBuilder(context, CommonsDatabase.class, "commons-flybits-db")
                            .addMigrations(MIGRATION_1_2)
                            .build();
                   /*
                    Room.inMemoryDatabaseBuilder(context.getApplicationContext(), ContextDatabase.class)
                            // To simplify the codelab, allow queries on the main thread.
                            // Don't do this on a real app! See PersistenceBasicSample for an example.
                            .allowMainThreadQueries()
                            .build();
                    */
        }
        return INSTANCE;
    }

    public static final Migration MIGRATION_1_2 = new Migration(1, 2) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL("ALTER TABLE user ADD isVerified INTEGER NOT NULL DEFAULT 0");
            database.execSQL("CREATE TABLE IF NOT EXISTS cachingentry (cachingkey TEXT NOT NULL, contentID TEXT NOT NULL, PRIMARY KEY(cachingkey, contentID))");
        }
    };

    public static void destroyInstance() {
        INSTANCE = null;
    }
}
